# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: matsim/pb/Ids.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='matsim/pb/Ids.proto',
  package='matsim.pb',
  syntax='proto3',
  serialized_options=b'\n\030org.matsim.core.utils.pbP\001',
  serialized_pb=b'\n\x13matsim/pb/Ids.proto\x12\tmatsim.pb\"E\n\x07ProtoId\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\x05\x12\x1f\n\x04type\x18\x03 \x01(\x0e\x32\x11.matsim.pb.IdType*\x9b\x01\n\x06IdType\x12\x0e\n\nID_UNKNOWN\x10\x00\x12\x10\n\x0cID_DEPARTURE\x10\x01\x12\x14\n\x10ID_TRANSIT_ROUTE\x10\x02\x12\x13\n\x0fID_TRANSIT_LINE\x10\x03\x12\x0e\n\nID_VEHICLE\x10\x04\x12\x0b\n\x07ID_LINK\x10\x05\x12\r\n\tID_PERSON\x10\x06\x12\x18\n\x14ID_ACTIVITY_FACILITY\x10\x07\x42\x1c\n\x18org.matsim.core.utils.pbP\x01\x62\x06proto3'
)

_IDTYPE = _descriptor.EnumDescriptor(
  name='IdType',
  full_name='matsim.pb.IdType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ID_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ID_DEPARTURE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ID_TRANSIT_ROUTE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ID_TRANSIT_LINE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ID_VEHICLE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ID_LINK', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ID_PERSON', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ID_ACTIVITY_FACILITY', index=7, number=7,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=106,
  serialized_end=261,
)
_sym_db.RegisterEnumDescriptor(_IDTYPE)

IdType = enum_type_wrapper.EnumTypeWrapper(_IDTYPE)
ID_UNKNOWN = 0
ID_DEPARTURE = 1
ID_TRANSIT_ROUTE = 2
ID_TRANSIT_LINE = 3
ID_VEHICLE = 4
ID_LINK = 5
ID_PERSON = 6
ID_ACTIVITY_FACILITY = 7



_PROTOID = _descriptor.Descriptor(
  name='ProtoId',
  full_name='matsim.pb.ProtoId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='matsim.pb.ProtoId.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index', full_name='matsim.pb.ProtoId.index', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='matsim.pb.ProtoId.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34,
  serialized_end=103,
)

_PROTOID.fields_by_name['type'].enum_type = _IDTYPE
DESCRIPTOR.message_types_by_name['ProtoId'] = _PROTOID
DESCRIPTOR.enum_types_by_name['IdType'] = _IDTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProtoId = _reflection.GeneratedProtocolMessageType('ProtoId', (_message.Message,), {
  'DESCRIPTOR' : _PROTOID,
  '__module__' : 'matsim.pb.Ids_pb2'
  # @@protoc_insertion_point(class_scope:matsim.pb.ProtoId)
  })
_sym_db.RegisterMessage(ProtoId)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: matsim/pb/Wireformat.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='matsim/pb/Wireformat.proto',
  package='matsim.pb',
  syntax='proto3',
  serialized_options=b'\n\030org.matsim.core.utils.pbP\001',
  serialized_pb=b'\n\x1amatsim/pb/Wireformat.proto\x12\tmatsim.pb\"L\n\x0cPBFileHeader\x12\x0f\n\x07version\x18\x01 \x01(\r\x12+\n\x0b\x63ontentType\x18\x02 \x01(\x0e\x32\x16.matsim.pb.ContentType*&\n\x0b\x43ontentType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x45VENTS\x10\x01\x42\x1c\n\x18org.matsim.core.utils.pbP\x01\x62\x06proto3'
)

_CONTENTTYPE = _descriptor.EnumDescriptor(
  name='ContentType',
  full_name='matsim.pb.ContentType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENTS', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=119,
  serialized_end=157,
)
_sym_db.RegisterEnumDescriptor(_CONTENTTYPE)

ContentType = enum_type_wrapper.EnumTypeWrapper(_CONTENTTYPE)
UNKNOWN = 0
EVENTS = 1



_PBFILEHEADER = _descriptor.Descriptor(
  name='PBFileHeader',
  full_name='matsim.pb.PBFileHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='matsim.pb.PBFileHeader.version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contentType', full_name='matsim.pb.PBFileHeader.contentType', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=41,
  serialized_end=117,
)

_PBFILEHEADER.fields_by_name['contentType'].enum_type = _CONTENTTYPE
DESCRIPTOR.message_types_by_name['PBFileHeader'] = _PBFILEHEADER
DESCRIPTOR.enum_types_by_name['ContentType'] = _CONTENTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PBFileHeader = _reflection.GeneratedProtocolMessageType('PBFileHeader', (_message.Message,), {
  'DESCRIPTOR' : _PBFILEHEADER,
  '__module__' : 'matsim.pb.Wireformat_pb2'
  # @@protoc_insertion_point(class_scope:matsim.pb.PBFileHeader)
  })
_sym_db.RegisterMessage(PBFileHeader)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: matsim/pb/Events.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from matsim.pb import Ids_pb2 as matsim_dot_pb_dot_Ids__pb2
from matsim.pb import Model_pb2 as matsim_dot_pb_dot_Model__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='matsim/pb/Events.proto',
  package='matsim.pb',
  syntax='proto3',
  serialized_options=b'\n\030org.matsim.core.utils.pbB\013ProtoEvents',
  serialized_pb=b'\n\x16matsim/pb/Events.proto\x12\tmatsim.pb\x1a\x13matsim/pb/Ids.proto\x1a\x15matsim/pb/Model.proto\".\n\nEventBatch\x12 \n\x06\x65vents\x18\x01 \x03(\x0b\x32\x10.matsim.pb.Event\"\xaa\x07\n\x05\x45vent\x12\x0c\n\x04time\x18\x01 \x01(\x01\x12%\n\x06\x63oords\x18\x02 \x01(\x0b\x32\x15.matsim.pb.Coordinate\x12*\n\x07generic\x18\x03 \x01(\x0b\x32\x17.matsim.pb.GenericEventH\x00\x12\x32\n\x0b\x61\x63tivityEnd\x18\x04 \x01(\x0b\x32\x1b.matsim.pb.ActivityEndEventH\x00\x12\x36\n\ractivityStart\x18\x05 \x01(\x0b\x32\x1d.matsim.pb.ActivityStartEventH\x00\x12.\n\tlinkEnter\x18\x06 \x01(\x0b\x32\x19.matsim.pb.LinkEnterEventH\x00\x12.\n\tlinkLeave\x18\x07 \x01(\x0b\x32\x19.matsim.pb.LinkLeaveEventH\x00\x12\x38\n\x0fpersonalArrival\x18\x08 \x01(\x0b\x32\x1d.matsim.pb.PersonArrivalEventH\x00\x12:\n\x0fpersonDeparture\x18\t \x01(\x0b\x32\x1f.matsim.pb.PersonDepartureEventH\x00\x12\x42\n\x13personEntersVehicle\x18\n \x01(\x0b\x32#.matsim.pb.PersonEntersVehicleEventH\x00\x12\x42\n\x13personLeavesVehicle\x18\x0b \x01(\x0b\x32#.matsim.pb.PersonLeavesVehicleEventH\x00\x12\x32\n\x0bpersonMoney\x18\x0c \x01(\x0b\x32\x1b.matsim.pb.PersonMoneyEventH\x00\x12\x32\n\x0bpersonStuck\x18\r \x01(\x0b\x32\x1b.matsim.pb.PersonStuckEventH\x00\x12\x42\n\x13transitDriverStarts\x18\x0e \x01(\x0b\x32#.matsim.pb.TransitDriverStartsEventH\x00\x12\x36\n\rvehicleAborts\x18\x0f \x01(\x0b\x32\x1d.matsim.pb.VehicleAbortsEventH\x00\x12\x44\n\x14vehicleEntersTraffic\x18\x10 \x01(\x0b\x32$.matsim.pb.VehicleEntersTrafficEventH\x00\x12\x44\n\x14vehicleLeavesTraffic\x18\x11 \x01(\x0b\x32$.matsim.pb.VehicleLeavesTrafficEventH\x00\x42\x06\n\x04type\"}\n\x0cGenericEvent\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x31\n\x05\x61ttrs\x18\x02 \x03(\x0b\x32\".matsim.pb.GenericEvent.AttrsEntry\x1a,\n\nAttrsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x95\x01\n\x10\x41\x63tivityEndEvent\x12\"\n\x06linkId\x18\x01 \x01(\x0b\x32\x12.matsim.pb.ProtoId\x12&\n\nfacilityId\x18\x02 \x01(\x0b\x32\x12.matsim.pb.ProtoId\x12$\n\x08personId\x18\x03 \x01(\x0b\x32\x12.matsim.pb.ProtoId\x12\x0f\n\x07\x61\x63ttype\x18\x04 \x01(\t\"\x97\x01\n\x12\x41\x63tivityStartEvent\x12\"\n\x06linkId\x18\x01 \x01(\x0b\x32\x12.matsim.pb.ProtoId\x12&\n\nfacilityId\x18\x02 \x01(\x0b\x32\x12.matsim.pb.ProtoId\x12$\n\x08personId\x18\x03 \x01(\x0b\x32\x12.matsim.pb.ProtoId\x12\x0f\n\x07\x61\x63ttype\x18\x04 \x01(\t\"[\n\x0eLinkEnterEvent\x12\"\n\x06linkId\x18\x01 \x01(\x0b\x32\x12.matsim.pb.ProtoId\x12%\n\tvehicleId\x18\x02 \x01(\x0b\x32\x12.matsim.pb.ProtoId\"[\n\x0eLinkLeaveEvent\x12\"\n\x06linkId\x18\x01 \x01(\x0b\x32\x12.matsim.pb.ProtoId\x12%\n\tvehicleId\x18\x02 \x01(\x0b\x32\x12.matsim.pb.ProtoId\"o\n\x12PersonArrivalEvent\x12\"\n\x06linkId\x18\x01 \x01(\x0b\x32\x12.matsim.pb.ProtoId\x12\x0f\n\x07legMode\x18\x02 \x01(\t\x12$\n\x08personId\x18\x03 \x01(\x0b\x32\x12.matsim.pb.ProtoId\"q\n\x14PersonDepartureEvent\x12\"\n\x06linkId\x18\x01 \x01(\x0b\x32\x12.matsim.pb.ProtoId\x12\x0f\n\x07legMode\x18\x02 \x01(\t\x12$\n\x08personId\x18\x03 \x01(\x0b\x32\x12.matsim.pb.ProtoId\"g\n\x18PersonEntersVehicleEvent\x12$\n\x08personId\x18\x01 \x01(\x0b\x32\x12.matsim.pb.ProtoId\x12%\n\tvehicleId\x18\x02 \x01(\x0b\x32\x12.matsim.pb.ProtoId\"g\n\x18PersonLeavesVehicleEvent\x12$\n\x08personId\x18\x01 \x01(\x0b\x32\x12.matsim.pb.ProtoId\x12%\n\tvehicleId\x18\x02 \x01(\x0b\x32\x12.matsim.pb.ProtoId\"u\n\x10PersonMoneyEvent\x12$\n\x08personId\x18\x01 \x01(\x0b\x32\x12.matsim.pb.ProtoId\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x01\x12\x0f\n\x07purpose\x18\x03 \x01(\t\x12\x1a\n\x12transactionPartner\x18\x04 \x01(\t\"m\n\x10PersonStuckEvent\x12$\n\x08personId\x18\x01 \x01(\x0b\x32\x12.matsim.pb.ProtoId\x12\"\n\x06linkId\x18\x02 \x01(\x0b\x32\x12.matsim.pb.ProtoId\x12\x0f\n\x07legMode\x18\x03 \x01(\t\"\xe7\x01\n\x18TransitDriverStartsEvent\x12$\n\x08\x64riverId\x18\x01 \x01(\x0b\x32\x12.matsim.pb.ProtoId\x12%\n\tvehicleId\x18\x02 \x01(\x0b\x32\x12.matsim.pb.ProtoId\x12*\n\x0etransitRouteId\x18\x03 \x01(\x0b\x32\x12.matsim.pb.ProtoId\x12)\n\rtransitLineId\x18\x04 \x01(\x0b\x32\x12.matsim.pb.ProtoId\x12\'\n\x0b\x64\x65partureId\x18\x05 \x01(\x0b\x32\x12.matsim.pb.ProtoId\"_\n\x12VehicleAbortsEvent\x12%\n\tvehicleId\x18\x01 \x01(\x0b\x32\x12.matsim.pb.ProtoId\x12\"\n\x06linkId\x18\x02 \x01(\x0b\x32\x12.matsim.pb.ProtoId\"\xc1\x01\n\x19VehicleEntersTrafficEvent\x12$\n\x08\x64riverId\x18\x01 \x01(\x0b\x32\x12.matsim.pb.ProtoId\x12\"\n\x06linkId\x18\x02 \x01(\x0b\x32\x12.matsim.pb.ProtoId\x12%\n\tvehicleId\x18\x03 \x01(\x0b\x32\x12.matsim.pb.ProtoId\x12\x13\n\x0bnetworkMode\x18\x04 \x01(\t\x12\x1e\n\x16relativePositionOnLink\x18\x05 \x01(\x01\"\xc1\x01\n\x19VehicleLeavesTrafficEvent\x12$\n\x08\x64riverId\x18\x01 \x01(\x0b\x32\x12.matsim.pb.ProtoId\x12\"\n\x06linkId\x18\x02 \x01(\x0b\x32\x12.matsim.pb.ProtoId\x12%\n\tvehicleId\x18\x03 \x01(\x0b\x32\x12.matsim.pb.ProtoId\x12\x13\n\x0bnetworkMode\x18\x04 \x01(\t\x12\x1e\n\x16relativePositionOnLink\x18\x05 \x01(\x01\x42\'\n\x18org.matsim.core.utils.pbB\x0bProtoEventsb\x06proto3'
  ,
  dependencies=[matsim_dot_pb_dot_Ids__pb2.DESCRIPTOR,matsim_dot_pb_dot_Model__pb2.DESCRIPTOR,])




_EVENTBATCH = _descriptor.Descriptor(
  name='EventBatch',
  full_name='matsim.pb.EventBatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='events', full_name='matsim.pb.EventBatch.events', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=127,
)


_EVENT = _descriptor.Descriptor(
  name='Event',
  full_name='matsim.pb.Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='matsim.pb.Event.time', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='coords', full_name='matsim.pb.Event.coords', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='generic', full_name='matsim.pb.Event.generic', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='activityEnd', full_name='matsim.pb.Event.activityEnd', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='activityStart', full_name='matsim.pb.Event.activityStart', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='linkEnter', full_name='matsim.pb.Event.linkEnter', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='linkLeave', full_name='matsim.pb.Event.linkLeave', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='personalArrival', full_name='matsim.pb.Event.personalArrival', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='personDeparture', full_name='matsim.pb.Event.personDeparture', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='personEntersVehicle', full_name='matsim.pb.Event.personEntersVehicle', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='personLeavesVehicle', full_name='matsim.pb.Event.personLeavesVehicle', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='personMoney', full_name='matsim.pb.Event.personMoney', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='personStuck', full_name='matsim.pb.Event.personStuck', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transitDriverStarts', full_name='matsim.pb.Event.transitDriverStarts', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vehicleAborts', full_name='matsim.pb.Event.vehicleAborts', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vehicleEntersTraffic', full_name='matsim.pb.Event.vehicleEntersTraffic', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vehicleLeavesTraffic', full_name='matsim.pb.Event.vehicleLeavesTraffic', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='matsim.pb.Event.type',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=130,
  serialized_end=1068,
)


_GENERICEVENT_ATTRSENTRY = _descriptor.Descriptor(
  name='AttrsEntry',
  full_name='matsim.pb.GenericEvent.AttrsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='matsim.pb.GenericEvent.AttrsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='matsim.pb.GenericEvent.AttrsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1151,
  serialized_end=1195,
)

_GENERICEVENT = _descriptor.Descriptor(
  name='GenericEvent',
  full_name='matsim.pb.GenericEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='matsim.pb.GenericEvent.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attrs', full_name='matsim.pb.GenericEvent.attrs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_GENERICEVENT_ATTRSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1070,
  serialized_end=1195,
)


_ACTIVITYENDEVENT = _descriptor.Descriptor(
  name='ActivityEndEvent',
  full_name='matsim.pb.ActivityEndEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='linkId', full_name='matsim.pb.ActivityEndEvent.linkId', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='facilityId', full_name='matsim.pb.ActivityEndEvent.facilityId', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='personId', full_name='matsim.pb.ActivityEndEvent.personId', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acttype', full_name='matsim.pb.ActivityEndEvent.acttype', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1198,
  serialized_end=1347,
)


_ACTIVITYSTARTEVENT = _descriptor.Descriptor(
  name='ActivityStartEvent',
  full_name='matsim.pb.ActivityStartEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='linkId', full_name='matsim.pb.ActivityStartEvent.linkId', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='facilityId', full_name='matsim.pb.ActivityStartEvent.facilityId', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='personId', full_name='matsim.pb.ActivityStartEvent.personId', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acttype', full_name='matsim.pb.ActivityStartEvent.acttype', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1350,
  serialized_end=1501,
)


_LINKENTEREVENT = _descriptor.Descriptor(
  name='LinkEnterEvent',
  full_name='matsim.pb.LinkEnterEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='linkId', full_name='matsim.pb.LinkEnterEvent.linkId', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vehicleId', full_name='matsim.pb.LinkEnterEvent.vehicleId', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1503,
  serialized_end=1594,
)


_LINKLEAVEEVENT = _descriptor.Descriptor(
  name='LinkLeaveEvent',
  full_name='matsim.pb.LinkLeaveEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='linkId', full_name='matsim.pb.LinkLeaveEvent.linkId', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vehicleId', full_name='matsim.pb.LinkLeaveEvent.vehicleId', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1596,
  serialized_end=1687,
)


_PERSONARRIVALEVENT = _descriptor.Descriptor(
  name='PersonArrivalEvent',
  full_name='matsim.pb.PersonArrivalEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='linkId', full_name='matsim.pb.PersonArrivalEvent.linkId', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='legMode', full_name='matsim.pb.PersonArrivalEvent.legMode', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='personId', full_name='matsim.pb.PersonArrivalEvent.personId', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1689,
  serialized_end=1800,
)


_PERSONDEPARTUREEVENT = _descriptor.Descriptor(
  name='PersonDepartureEvent',
  full_name='matsim.pb.PersonDepartureEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='linkId', full_name='matsim.pb.PersonDepartureEvent.linkId', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='legMode', full_name='matsim.pb.PersonDepartureEvent.legMode', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='personId', full_name='matsim.pb.PersonDepartureEvent.personId', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1802,
  serialized_end=1915,
)


_PERSONENTERSVEHICLEEVENT = _descriptor.Descriptor(
  name='PersonEntersVehicleEvent',
  full_name='matsim.pb.PersonEntersVehicleEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='personId', full_name='matsim.pb.PersonEntersVehicleEvent.personId', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vehicleId', full_name='matsim.pb.PersonEntersVehicleEvent.vehicleId', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1917,
  serialized_end=2020,
)


_PERSONLEAVESVEHICLEEVENT = _descriptor.Descriptor(
  name='PersonLeavesVehicleEvent',
  full_name='matsim.pb.PersonLeavesVehicleEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='personId', full_name='matsim.pb.PersonLeavesVehicleEvent.personId', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vehicleId', full_name='matsim.pb.PersonLeavesVehicleEvent.vehicleId', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2022,
  serialized_end=2125,
)


_PERSONMONEYEVENT = _descriptor.Descriptor(
  name='PersonMoneyEvent',
  full_name='matsim.pb.PersonMoneyEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='personId', full_name='matsim.pb.PersonMoneyEvent.personId', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amount', full_name='matsim.pb.PersonMoneyEvent.amount', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='purpose', full_name='matsim.pb.PersonMoneyEvent.purpose', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transactionPartner', full_name='matsim.pb.PersonMoneyEvent.transactionPartner', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2127,
  serialized_end=2244,
)


_PERSONSTUCKEVENT = _descriptor.Descriptor(
  name='PersonStuckEvent',
  full_name='matsim.pb.PersonStuckEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='personId', full_name='matsim.pb.PersonStuckEvent.personId', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='linkId', full_name='matsim.pb.PersonStuckEvent.linkId', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='legMode', full_name='matsim.pb.PersonStuckEvent.legMode', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2246,
  serialized_end=2355,
)


_TRANSITDRIVERSTARTSEVENT = _descriptor.Descriptor(
  name='TransitDriverStartsEvent',
  full_name='matsim.pb.TransitDriverStartsEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='driverId', full_name='matsim.pb.TransitDriverStartsEvent.driverId', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vehicleId', full_name='matsim.pb.TransitDriverStartsEvent.vehicleId', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transitRouteId', full_name='matsim.pb.TransitDriverStartsEvent.transitRouteId', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transitLineId', full_name='matsim.pb.TransitDriverStartsEvent.transitLineId', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='departureId', full_name='matsim.pb.TransitDriverStartsEvent.departureId', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2358,
  serialized_end=2589,
)


_VEHICLEABORTSEVENT = _descriptor.Descriptor(
  name='VehicleAbortsEvent',
  full_name='matsim.pb.VehicleAbortsEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vehicleId', full_name='matsim.pb.VehicleAbortsEvent.vehicleId', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='linkId', full_name='matsim.pb.VehicleAbortsEvent.linkId', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2591,
  serialized_end=2686,
)


_VEHICLEENTERSTRAFFICEVENT = _descriptor.Descriptor(
  name='VehicleEntersTrafficEvent',
  full_name='matsim.pb.VehicleEntersTrafficEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='driverId', full_name='matsim.pb.VehicleEntersTrafficEvent.driverId', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='linkId', full_name='matsim.pb.VehicleEntersTrafficEvent.linkId', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vehicleId', full_name='matsim.pb.VehicleEntersTrafficEvent.vehicleId', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='networkMode', full_name='matsim.pb.VehicleEntersTrafficEvent.networkMode', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relativePositionOnLink', full_name='matsim.pb.VehicleEntersTrafficEvent.relativePositionOnLink', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2689,
  serialized_end=2882,
)


_VEHICLELEAVESTRAFFICEVENT = _descriptor.Descriptor(
  name='VehicleLeavesTrafficEvent',
  full_name='matsim.pb.VehicleLeavesTrafficEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='driverId', full_name='matsim.pb.VehicleLeavesTrafficEvent.driverId', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='linkId', full_name='matsim.pb.VehicleLeavesTrafficEvent.linkId', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vehicleId', full_name='matsim.pb.VehicleLeavesTrafficEvent.vehicleId', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='networkMode', full_name='matsim.pb.VehicleLeavesTrafficEvent.networkMode', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relativePositionOnLink', full_name='matsim.pb.VehicleLeavesTrafficEvent.relativePositionOnLink', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2885,
  serialized_end=3078,
)

_EVENTBATCH.fields_by_name['events'].message_type = _EVENT
_EVENT.fields_by_name['coords'].message_type = matsim_dot_pb_dot_Model__pb2._COORDINATE
_EVENT.fields_by_name['generic'].message_type = _GENERICEVENT
_EVENT.fields_by_name['activityEnd'].message_type = _ACTIVITYENDEVENT
_EVENT.fields_by_name['activityStart'].message_type = _ACTIVITYSTARTEVENT
_EVENT.fields_by_name['linkEnter'].message_type = _LINKENTEREVENT
_EVENT.fields_by_name['linkLeave'].message_type = _LINKLEAVEEVENT
_EVENT.fields_by_name['personalArrival'].message_type = _PERSONARRIVALEVENT
_EVENT.fields_by_name['personDeparture'].message_type = _PERSONDEPARTUREEVENT
_EVENT.fields_by_name['personEntersVehicle'].message_type = _PERSONENTERSVEHICLEEVENT
_EVENT.fields_by_name['personLeavesVehicle'].message_type = _PERSONLEAVESVEHICLEEVENT
_EVENT.fields_by_name['personMoney'].message_type = _PERSONMONEYEVENT
_EVENT.fields_by_name['personStuck'].message_type = _PERSONSTUCKEVENT
_EVENT.fields_by_name['transitDriverStarts'].message_type = _TRANSITDRIVERSTARTSEVENT
_EVENT.fields_by_name['vehicleAborts'].message_type = _VEHICLEABORTSEVENT
_EVENT.fields_by_name['vehicleEntersTraffic'].message_type = _VEHICLEENTERSTRAFFICEVENT
_EVENT.fields_by_name['vehicleLeavesTraffic'].message_type = _VEHICLELEAVESTRAFFICEVENT
_EVENT.oneofs_by_name['type'].fields.append(
  _EVENT.fields_by_name['generic'])
_EVENT.fields_by_name['generic'].containing_oneof = _EVENT.oneofs_by_name['type']
_EVENT.oneofs_by_name['type'].fields.append(
  _EVENT.fields_by_name['activityEnd'])
_EVENT.fields_by_name['activityEnd'].containing_oneof = _EVENT.oneofs_by_name['type']
_EVENT.oneofs_by_name['type'].fields.append(
  _EVENT.fields_by_name['activityStart'])
_EVENT.fields_by_name['activityStart'].containing_oneof = _EVENT.oneofs_by_name['type']
_EVENT.oneofs_by_name['type'].fields.append(
  _EVENT.fields_by_name['linkEnter'])
_EVENT.fields_by_name['linkEnter'].containing_oneof = _EVENT.oneofs_by_name['type']
_EVENT.oneofs_by_name['type'].fields.append(
  _EVENT.fields_by_name['linkLeave'])
_EVENT.fields_by_name['linkLeave'].containing_oneof = _EVENT.oneofs_by_name['type']
_EVENT.oneofs_by_name['type'].fields.append(
  _EVENT.fields_by_name['personalArrival'])
_EVENT.fields_by_name['personalArrival'].containing_oneof = _EVENT.oneofs_by_name['type']
_EVENT.oneofs_by_name['type'].fields.append(
  _EVENT.fields_by_name['personDeparture'])
_EVENT.fields_by_name['personDeparture'].containing_oneof = _EVENT.oneofs_by_name['type']
_EVENT.oneofs_by_name['type'].fields.append(
  _EVENT.fields_by_name['personEntersVehicle'])
_EVENT.fields_by_name['personEntersVehicle'].containing_oneof = _EVENT.oneofs_by_name['type']
_EVENT.oneofs_by_name['type'].fields.append(
  _EVENT.fields_by_name['personLeavesVehicle'])
_EVENT.fields_by_name['personLeavesVehicle'].containing_oneof = _EVENT.oneofs_by_name['type']
_EVENT.oneofs_by_name['type'].fields.append(
  _EVENT.fields_by_name['personMoney'])
_EVENT.fields_by_name['personMoney'].containing_oneof = _EVENT.oneofs_by_name['type']
_EVENT.oneofs_by_name['type'].fields.append(
  _EVENT.fields_by_name['personStuck'])
_EVENT.fields_by_name['personStuck'].containing_oneof = _EVENT.oneofs_by_name['type']
_EVENT.oneofs_by_name['type'].fields.append(
  _EVENT.fields_by_name['transitDriverStarts'])
_EVENT.fields_by_name['transitDriverStarts'].containing_oneof = _EVENT.oneofs_by_name['type']
_EVENT.oneofs_by_name['type'].fields.append(
  _EVENT.fields_by_name['vehicleAborts'])
_EVENT.fields_by_name['vehicleAborts'].containing_oneof = _EVENT.oneofs_by_name['type']
_EVENT.oneofs_by_name['type'].fields.append(
  _EVENT.fields_by_name['vehicleEntersTraffic'])
_EVENT.fields_by_name['vehicleEntersTraffic'].containing_oneof = _EVENT.oneofs_by_name['type']
_EVENT.oneofs_by_name['type'].fields.append(
  _EVENT.fields_by_name['vehicleLeavesTraffic'])
_EVENT.fields_by_name['vehicleLeavesTraffic'].containing_oneof = _EVENT.oneofs_by_name['type']
_GENERICEVENT_ATTRSENTRY.containing_type = _GENERICEVENT
_GENERICEVENT.fields_by_name['attrs'].message_type = _GENERICEVENT_ATTRSENTRY
_ACTIVITYENDEVENT.fields_by_name['linkId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_ACTIVITYENDEVENT.fields_by_name['facilityId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_ACTIVITYENDEVENT.fields_by_name['personId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_ACTIVITYSTARTEVENT.fields_by_name['linkId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_ACTIVITYSTARTEVENT.fields_by_name['facilityId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_ACTIVITYSTARTEVENT.fields_by_name['personId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_LINKENTEREVENT.fields_by_name['linkId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_LINKENTEREVENT.fields_by_name['vehicleId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_LINKLEAVEEVENT.fields_by_name['linkId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_LINKLEAVEEVENT.fields_by_name['vehicleId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_PERSONARRIVALEVENT.fields_by_name['linkId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_PERSONARRIVALEVENT.fields_by_name['personId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_PERSONDEPARTUREEVENT.fields_by_name['linkId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_PERSONDEPARTUREEVENT.fields_by_name['personId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_PERSONENTERSVEHICLEEVENT.fields_by_name['personId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_PERSONENTERSVEHICLEEVENT.fields_by_name['vehicleId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_PERSONLEAVESVEHICLEEVENT.fields_by_name['personId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_PERSONLEAVESVEHICLEEVENT.fields_by_name['vehicleId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_PERSONMONEYEVENT.fields_by_name['personId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_PERSONSTUCKEVENT.fields_by_name['personId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_PERSONSTUCKEVENT.fields_by_name['linkId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_TRANSITDRIVERSTARTSEVENT.fields_by_name['driverId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_TRANSITDRIVERSTARTSEVENT.fields_by_name['vehicleId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_TRANSITDRIVERSTARTSEVENT.fields_by_name['transitRouteId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_TRANSITDRIVERSTARTSEVENT.fields_by_name['transitLineId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_TRANSITDRIVERSTARTSEVENT.fields_by_name['departureId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_VEHICLEABORTSEVENT.fields_by_name['vehicleId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_VEHICLEABORTSEVENT.fields_by_name['linkId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_VEHICLEENTERSTRAFFICEVENT.fields_by_name['driverId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_VEHICLEENTERSTRAFFICEVENT.fields_by_name['linkId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_VEHICLEENTERSTRAFFICEVENT.fields_by_name['vehicleId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_VEHICLELEAVESTRAFFICEVENT.fields_by_name['driverId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_VEHICLELEAVESTRAFFICEVENT.fields_by_name['linkId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
_VEHICLELEAVESTRAFFICEVENT.fields_by_name['vehicleId'].message_type = matsim_dot_pb_dot_Ids__pb2._PROTOID
DESCRIPTOR.message_types_by_name['EventBatch'] = _EVENTBATCH
DESCRIPTOR.message_types_by_name['Event'] = _EVENT
DESCRIPTOR.message_types_by_name['GenericEvent'] = _GENERICEVENT
DESCRIPTOR.message_types_by_name['ActivityEndEvent'] = _ACTIVITYENDEVENT
DESCRIPTOR.message_types_by_name['ActivityStartEvent'] = _ACTIVITYSTARTEVENT
DESCRIPTOR.message_types_by_name['LinkEnterEvent'] = _LINKENTEREVENT
DESCRIPTOR.message_types_by_name['LinkLeaveEvent'] = _LINKLEAVEEVENT
DESCRIPTOR.message_types_by_name['PersonArrivalEvent'] = _PERSONARRIVALEVENT
DESCRIPTOR.message_types_by_name['PersonDepartureEvent'] = _PERSONDEPARTUREEVENT
DESCRIPTOR.message_types_by_name['PersonEntersVehicleEvent'] = _PERSONENTERSVEHICLEEVENT
DESCRIPTOR.message_types_by_name['PersonLeavesVehicleEvent'] = _PERSONLEAVESVEHICLEEVENT
DESCRIPTOR.message_types_by_name['PersonMoneyEvent'] = _PERSONMONEYEVENT
DESCRIPTOR.message_types_by_name['PersonStuckEvent'] = _PERSONSTUCKEVENT
DESCRIPTOR.message_types_by_name['TransitDriverStartsEvent'] = _TRANSITDRIVERSTARTSEVENT
DESCRIPTOR.message_types_by_name['VehicleAbortsEvent'] = _VEHICLEABORTSEVENT
DESCRIPTOR.message_types_by_name['VehicleEntersTrafficEvent'] = _VEHICLEENTERSTRAFFICEVENT
DESCRIPTOR.message_types_by_name['VehicleLeavesTrafficEvent'] = _VEHICLELEAVESTRAFFICEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EventBatch = _reflection.GeneratedProtocolMessageType('EventBatch', (_message.Message,), {
  'DESCRIPTOR' : _EVENTBATCH,
  '__module__' : 'matsim.pb.Events_pb2'
  # @@protoc_insertion_point(class_scope:matsim.pb.EventBatch)
  })
_sym_db.RegisterMessage(EventBatch)

Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), {
  'DESCRIPTOR' : _EVENT,
  '__module__' : 'matsim.pb.Events_pb2'
  # @@protoc_insertion_point(class_scope:matsim.pb.Event)
  })
_sym_db.RegisterMessage(Event)

GenericEvent = _reflection.GeneratedProtocolMessageType('GenericEvent', (_message.Message,), {

  'AttrsEntry' : _reflection.GeneratedProtocolMessageType('AttrsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GENERICEVENT_ATTRSENTRY,
    '__module__' : 'matsim.pb.Events_pb2'
    # @@protoc_insertion_point(class_scope:matsim.pb.GenericEvent.AttrsEntry)
    })
  ,
  'DESCRIPTOR' : _GENERICEVENT,
  '__module__' : 'matsim.pb.Events_pb2'
  # @@protoc_insertion_point(class_scope:matsim.pb.GenericEvent)
  })
_sym_db.RegisterMessage(GenericEvent)
_sym_db.RegisterMessage(GenericEvent.AttrsEntry)

ActivityEndEvent = _reflection.GeneratedProtocolMessageType('ActivityEndEvent', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYENDEVENT,
  '__module__' : 'matsim.pb.Events_pb2'
  # @@protoc_insertion_point(class_scope:matsim.pb.ActivityEndEvent)
  })
_sym_db.RegisterMessage(ActivityEndEvent)

ActivityStartEvent = _reflection.GeneratedProtocolMessageType('ActivityStartEvent', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYSTARTEVENT,
  '__module__' : 'matsim.pb.Events_pb2'
  # @@protoc_insertion_point(class_scope:matsim.pb.ActivityStartEvent)
  })
_sym_db.RegisterMessage(ActivityStartEvent)

LinkEnterEvent = _reflection.GeneratedProtocolMessageType('LinkEnterEvent', (_message.Message,), {
  'DESCRIPTOR' : _LINKENTEREVENT,
  '__module__' : 'matsim.pb.Events_pb2'
  # @@protoc_insertion_point(class_scope:matsim.pb.LinkEnterEvent)
  })
_sym_db.RegisterMessage(LinkEnterEvent)

LinkLeaveEvent = _reflection.GeneratedProtocolMessageType('LinkLeaveEvent', (_message.Message,), {
  'DESCRIPTOR' : _LINKLEAVEEVENT,
  '__module__' : 'matsim.pb.Events_pb2'
  # @@protoc_insertion_point(class_scope:matsim.pb.LinkLeaveEvent)
  })
_sym_db.RegisterMessage(LinkLeaveEvent)

PersonArrivalEvent = _reflection.GeneratedProtocolMessageType('PersonArrivalEvent', (_message.Message,), {
  'DESCRIPTOR' : _PERSONARRIVALEVENT,
  '__module__' : 'matsim.pb.Events_pb2'
  # @@protoc_insertion_point(class_scope:matsim.pb.PersonArrivalEvent)
  })
_sym_db.RegisterMessage(PersonArrivalEvent)

PersonDepartureEvent = _reflection.GeneratedProtocolMessageType('PersonDepartureEvent', (_message.Message,), {
  'DESCRIPTOR' : _PERSONDEPARTUREEVENT,
  '__module__' : 'matsim.pb.Events_pb2'
  # @@protoc_insertion_point(class_scope:matsim.pb.PersonDepartureEvent)
  })
_sym_db.RegisterMessage(PersonDepartureEvent)

PersonEntersVehicleEvent = _reflection.GeneratedProtocolMessageType('PersonEntersVehicleEvent', (_message.Message,), {
  'DESCRIPTOR' : _PERSONENTERSVEHICLEEVENT,
  '__module__' : 'matsim.pb.Events_pb2'
  # @@protoc_insertion_point(class_scope:matsim.pb.PersonEntersVehicleEvent)
  })
_sym_db.RegisterMessage(PersonEntersVehicleEvent)

PersonLeavesVehicleEvent = _reflection.GeneratedProtocolMessageType('PersonLeavesVehicleEvent', (_message.Message,), {
  'DESCRIPTOR' : _PERSONLEAVESVEHICLEEVENT,
  '__module__' : 'matsim.pb.Events_pb2'
  # @@protoc_insertion_point(class_scope:matsim.pb.PersonLeavesVehicleEvent)
  })
_sym_db.RegisterMessage(PersonLeavesVehicleEvent)

PersonMoneyEvent = _reflection.GeneratedProtocolMessageType('PersonMoneyEvent', (_message.Message,), {
  'DESCRIPTOR' : _PERSONMONEYEVENT,
  '__module__' : 'matsim.pb.Events_pb2'
  # @@protoc_insertion_point(class_scope:matsim.pb.PersonMoneyEvent)
  })
_sym_db.RegisterMessage(PersonMoneyEvent)

PersonStuckEvent = _reflection.GeneratedProtocolMessageType('PersonStuckEvent', (_message.Message,), {
  'DESCRIPTOR' : _PERSONSTUCKEVENT,
  '__module__' : 'matsim.pb.Events_pb2'
  # @@protoc_insertion_point(class_scope:matsim.pb.PersonStuckEvent)
  })
_sym_db.RegisterMessage(PersonStuckEvent)

TransitDriverStartsEvent = _reflection.GeneratedProtocolMessageType('TransitDriverStartsEvent', (_message.Message,), {
  'DESCRIPTOR' : _TRANSITDRIVERSTARTSEVENT,
  '__module__' : 'matsim.pb.Events_pb2'
  # @@protoc_insertion_point(class_scope:matsim.pb.TransitDriverStartsEvent)
  })
_sym_db.RegisterMessage(TransitDriverStartsEvent)

VehicleAbortsEvent = _reflection.GeneratedProtocolMessageType('VehicleAbortsEvent', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLEABORTSEVENT,
  '__module__' : 'matsim.pb.Events_pb2'
  # @@protoc_insertion_point(class_scope:matsim.pb.VehicleAbortsEvent)
  })
_sym_db.RegisterMessage(VehicleAbortsEvent)

VehicleEntersTrafficEvent = _reflection.GeneratedProtocolMessageType('VehicleEntersTrafficEvent', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLEENTERSTRAFFICEVENT,
  '__module__' : 'matsim.pb.Events_pb2'
  # @@protoc_insertion_point(class_scope:matsim.pb.VehicleEntersTrafficEvent)
  })
_sym_db.RegisterMessage(VehicleEntersTrafficEvent)

VehicleLeavesTrafficEvent = _reflection.GeneratedProtocolMessageType('VehicleLeavesTrafficEvent', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLELEAVESTRAFFICEVENT,
  '__module__' : 'matsim.pb.Events_pb2'
  # @@protoc_insertion_point(class_scope:matsim.pb.VehicleLeavesTrafficEvent)
  })
_sym_db.RegisterMessage(VehicleLeavesTrafficEvent)


DESCRIPTOR._options = None
_GENERICEVENT_ATTRSENTRY._options = None
# @@protoc_insertion_point(module_scope)
